@@ -2,12 +2,12 @@ from rest_framework.viewsets import ModelViewSet
 
 from .serializers import (
     BGPSessionSerializer, RoutingPolicySerializer, BGPPeerGroupSerializer,
-    CommunitySerializer, PrefixListSerializer
+    CommunitySerializer, PrefixListSerializer, PrefixListRuleSerializer, RoutingPolicyRuleSerializer
 )
-from netbox_bgp.models import BGPSession, RoutingPolicy, BGPPeerGroup, Community, PrefixList
+from netbox_bgp.models import BGPSession, RoutingPolicy, BGPPeerGroup, Community, PrefixList, PrefixListRule, RoutingPolicyRule
 from netbox_bgp.filters import (
     BGPSessionFilterSet, RoutingPolicyFilterSet, BGPPeerGroupFilterSet,
-    CommunityFilterSet, PrefixListFilterSet
+    CommunityFilterSet, PrefixListFilterSet, PrefixListRuleFilterSet, RoutingPolicyRuleFilterSet
 )
 
 
@@ -23,6 +23,12 @@ class RoutingPolicyViewSet(ModelViewSet):
     filterset_class = RoutingPolicyFilterSet
 
 
+class RoutingPolicyRuleViewSet(ModelViewSet):
+    queryset = RoutingPolicyRule.objects.all()
+    serializer_class = RoutingPolicyRuleSerializer
+    filterset_class = RoutingPolicyRuleFilterSet
+
+
 class BGPPeerGroupViewSet(ModelViewSet):
     queryset = BGPPeerGroup.objects.all()
     serializer_class = BGPPeerGroupSerializer
@@ -39,3 +45,8 @@ class PrefixListViewSet(ModelViewSet):
     queryset = PrefixList.objects.all()
     serializer_class = PrefixListSerializer
     filterset_class = PrefixListFilterSet
+
+class PrefixListRuleViewSet(ModelViewSet):
+    queryset = PrefixListRule.objects.all()
+    serializer_class = PrefixListRuleSerializer
+    filterset_class = PrefixListRuleFilterSet
